[Lldb-commits] [lldb] r333399 - Typo fixes.

Bruce Mitchener via lldb-commits lldb-commits at lists.llvm.org
Tue May 29 02:10:46 PDT 2018


Author: brucem
Date: Tue May 29 02:10:46 2018
New Revision: 333399

URL: http://llvm.org/viewvc/llvm-project?rev=333399&view=rev
Log:
Typo fixes.

Reviewers: javed.absar

Subscribers: ki.stfu, JDevlieghere, lldb-commits

Differential Revision: https://reviews.llvm.org/D47421

Modified:
    lldb/trunk/include/lldb/Breakpoint/BreakpointID.h
    lldb/trunk/include/lldb/Core/Address.h
    lldb/trunk/include/lldb/Core/Broadcaster.h
    lldb/trunk/include/lldb/Target/ExecutionContext.h
    lldb/trunk/include/lldb/Target/Process.h
    lldb/trunk/include/lldb/Utility/ArchSpec.h
    lldb/trunk/packages/Python/lldbsuite/test/functionalities/apropos_with_process/TestAproposWithProcess.py
    lldb/trunk/packages/Python/lldbsuite/test/functionalities/memory/find/TestMemoryFind.py
    lldb/trunk/packages/Python/lldbsuite/test/functionalities/memory/read/TestMemoryRead.py
    lldb/trunk/packages/Python/lldbsuite/test/functionalities/nested_alias/TestNestedAlias.py
    lldb/trunk/packages/Python/lldbsuite/test/functionalities/thread/exit_during_break/main.cpp
    lldb/trunk/packages/Python/lldbsuite/test/lang/cpp/unsigned_types/TestUnsignedTypes.py
    lldb/trunk/packages/Python/lldbsuite/test/lang/objc/bitfield_ivars/TestBitfieldIvars.py
    lldb/trunk/source/Commands/CommandObjectWatchpointCommand.cpp
    lldb/trunk/source/Core/Communication.cpp
    lldb/trunk/source/Core/ValueObjectVariable.cpp
    lldb/trunk/source/Expression/DWARFExpression.cpp
    lldb/trunk/source/Plugins/Architecture/Arm/ArchitectureArm.cpp
    lldb/trunk/source/Plugins/ExpressionParser/Clang/ClangExpressionParser.cpp
    lldb/trunk/source/Plugins/LanguageRuntime/RenderScript/RenderScriptRuntime/RenderScriptRuntime.cpp
    lldb/trunk/source/Plugins/LanguageRuntime/RenderScript/RenderScriptRuntime/RenderScriptx86ABIFixups.cpp
    lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm.h
    lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.h
    lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_ppc64le.h
    lldb/trunk/source/Plugins/Process/Linux/ProcessorTrace.h
    lldb/trunk/source/Plugins/Process/MacOSX-Kernel/ProcessKDP.cpp
    lldb/trunk/source/Plugins/Process/gdb-remote/ProcessGDBRemote.cpp
    lldb/trunk/source/Plugins/StructuredData/DarwinLog/StructuredDataDarwinLog.cpp
    lldb/trunk/source/Plugins/UnwindAssembly/InstEmulation/UnwindAssemblyInstEmulation.cpp
    lldb/trunk/source/Target/TargetList.cpp
    lldb/trunk/source/Utility/Status.cpp
    lldb/trunk/tools/debugserver/source/MacOSX/MachProcess.mm
    lldb/trunk/tools/debugserver/source/RNBServices.cpp
    lldb/trunk/tools/lldb-mi/MICmnResources.cpp
    lldb/trunk/tools/lldb-mi/MIReadMe.txt
    lldb/trunk/www/remote.html
    lldb/trunk/www/tutorial.html

Modified: lldb/trunk/include/lldb/Breakpoint/BreakpointID.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Breakpoint/BreakpointID.h?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Breakpoint/BreakpointID.h (original)
+++ lldb/trunk/include/lldb/Breakpoint/BreakpointID.h Tue May 29 02:10:46 2018
@@ -57,7 +57,7 @@ public:
 
   //------------------------------------------------------------------
   /// Takes an input string containing the description of a breakpoint or
-  /// breakpoint and location and returns the a BreakpointID filled out with
+  /// breakpoint and location and returns a BreakpointID filled out with
   /// the proper id and location.
   ///
   /// @param[in] input

Modified: lldb/trunk/include/lldb/Core/Address.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Core/Address.h?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Core/Address.h (original)
+++ lldb/trunk/include/lldb/Core/Address.h Tue May 29 02:10:46 2018
@@ -370,7 +370,7 @@ public:
   /// Check if the object state is valid.
   ///
   /// A valid Address object contains either a section pointer and
-  /// and offset (for section offset based addresses), or just a valid offset
+  /// offset (for section offset based addresses), or just a valid offset
   /// (for absolute addresses that have no section).
   ///
   /// @return
@@ -390,7 +390,7 @@ public:
   //------------------------------------------------------------------
   /// Resolve a file virtual address using a section list.
   ///
-  /// Given a list of sections, attempt to resolve \a addr as a an offset into
+  /// Given a list of sections, attempt to resolve \a addr as an offset into
   /// one of the file sections.
   ///
   /// @return

Modified: lldb/trunk/include/lldb/Core/Broadcaster.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Core/Broadcaster.h?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Core/Broadcaster.h (original)
+++ lldb/trunk/include/lldb/Core/Broadcaster.h Tue May 29 02:10:46 2018
@@ -548,7 +548,7 @@ protected:
     llvm::SmallVector<std::pair<lldb::ListenerSP, uint32_t &>, 4>
     GetListeners();
 
-    Broadcaster &m_broadcaster;    ///< The broadcsater that this implements
+    Broadcaster &m_broadcaster;    ///< The broadcaster that this implements
     event_names_map m_event_names; ///< Optionally define event names for
                                    ///readability and logging for each event bit
     collection m_listeners; ///< A list of Listener / event_mask pairs that are

Modified: lldb/trunk/include/lldb/Target/ExecutionContext.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Target/ExecutionContext.h?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Target/ExecutionContext.h (original)
+++ lldb/trunk/include/lldb/Target/ExecutionContext.h Tue May 29 02:10:46 2018
@@ -35,8 +35,8 @@ namespace lldb_private {
 /// contexts: ExecutionContextRef and ExecutionContext. Both of these objects
 /// are described below.
 ///
-/// Not all objects in an ExectionContext objects will be valid. If you want
-/// to refer strongly (ExectionContext) or weakly (ExectionContextRef) to a
+/// Not all objects in an ExecutionContext objects will be valid. If you want
+/// to refer strongly (ExecutionContext) or weakly (ExecutionContextRef) to a
 /// process, then only the process and target references will be valid. For
 /// threads, only the thread, process and target references will be filled in.
 /// For frames, all of the objects will be filled in.

Modified: lldb/trunk/include/lldb/Target/Process.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Target/Process.h?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Target/Process.h (original)
+++ lldb/trunk/include/lldb/Target/Process.h Tue May 29 02:10:46 2018
@@ -761,7 +761,7 @@ public:
   /// This object will be used to resolve plug-in commands and can be
   /// triggered by a call to:
   ///
-  ///     (lldb) process commmand <args>
+  ///     (lldb) process command <args>
   ///
   /// @return
   ///     A CommandObject which can be one of the concrete subclasses

Modified: lldb/trunk/include/lldb/Utility/ArchSpec.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Utility/ArchSpec.h?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Utility/ArchSpec.h (original)
+++ lldb/trunk/include/lldb/Utility/ArchSpec.h Tue May 29 02:10:46 2018
@@ -293,7 +293,7 @@ public:
   //------------------------------------------------------------------
   /// Returns a static string representing the current architecture.
   ///
-  /// @return A static string correcponding to the current
+  /// @return A static string corresponding to the current
   ///         architecture.
   //------------------------------------------------------------------
   const char *GetArchitectureName() const;
@@ -419,7 +419,7 @@ public:
   /// @return True if the object, and CPU were successfully set.
   ///
   /// As a side effect, the vendor value is usually set to unknown. The
-  /// exections are
+  /// exceptions are
   ///   aarch64-apple-ios
   ///   arm-apple-ios
   ///   thumb-apple-ios
@@ -487,14 +487,14 @@ public:
   uint32_t GetCodeByteSize() const;
 
   //------------------------------------------------------------------
-  /// Architecture tripple accessor.
+  /// Architecture triple accessor.
   ///
   /// @return A triple describing this ArchSpec.
   //------------------------------------------------------------------
   llvm::Triple &GetTriple() { return m_triple; }
 
   //------------------------------------------------------------------
-  /// Architecture tripple accessor.
+  /// Architecture triple accessor.
   ///
   /// @return A triple describing this ArchSpec.
   //------------------------------------------------------------------
@@ -503,7 +503,7 @@ public:
   void DumpTriple(Stream &s) const;
 
   //------------------------------------------------------------------
-  /// Architecture tripple setter.
+  /// Architecture triple setter.
   ///
   /// Configures this ArchSpec according to the given triple.  If the triple
   /// has unknown components in all of the vendor, OS, and the optional
@@ -527,7 +527,7 @@ public:
   lldb::ByteOrder GetDefaultEndian() const;
 
   //------------------------------------------------------------------
-  /// Returns true if 'char' is a signed type by defualt in the architecture
+  /// Returns true if 'char' is a signed type by default in the architecture
   /// false otherwise
   ///
   /// @return True if 'char' is a signed type by default on the

Modified: lldb/trunk/packages/Python/lldbsuite/test/functionalities/apropos_with_process/TestAproposWithProcess.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/packages/Python/lldbsuite/test/functionalities/apropos_with_process/TestAproposWithProcess.py?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/packages/Python/lldbsuite/test/functionalities/memory/find/TestMemoryFind.py (original)
+++ lldb/trunk/packages/Python/lldbsuite/test/functionalities/memory/find/TestMemoryFind.py Tue May 29 02:10:46 2018
@@ -31,7 +31,7 @@ class MemoryFindTestCase(TestBase):
         exe = self.getBuildArtifact("a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)
 
-        # Break in main() aftre the variables are assigned values.
+        # Break in main() after the variables are assigned values.
         lldbutil.run_break_set_by_file_and_line(
             self, "main.cpp", self.line, num_expected_locations=1, loc_exact=True)
 

Modified: lldb/trunk/packages/Python/lldbsuite/test/functionalities/memory/read/TestMemoryRead.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/packages/Python/lldbsuite/test/functionalities/memory/read/TestMemoryRead.py?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/packages/Python/lldbsuite/test/functionalities/memory/read/TestMemoryRead.py (original)
+++ lldb/trunk/packages/Python/lldbsuite/test/functionalities/memory/read/TestMemoryRead.py Tue May 29 02:10:46 2018
@@ -29,7 +29,7 @@ class MemoryReadTestCase(TestBase):
         exe = self.getBuildArtifact("a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)
 
-        # Break in main() aftre the variables are assigned values.
+        # Break in main() after the variables are assigned values.
         lldbutil.run_break_set_by_file_and_line(
             self, "main.cpp", self.line, num_expected_locations=1, loc_exact=True)
 

Modified: lldb/trunk/packages/Python/lldbsuite/test/functionalities/nested_alias/TestNestedAlias.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/packages/Python/lldbsuite/test/functionalities/nested_alias/TestNestedAlias.py?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/packages/Python/lldbsuite/test/functionalities/nested_alias/TestNestedAlias.py (original)
+++ lldb/trunk/packages/Python/lldbsuite/test/functionalities/nested_alias/TestNestedAlias.py Tue May 29 02:10:46 2018
@@ -29,7 +29,7 @@ class NestedAliasTestCase(TestBase):
         exe = self.getBuildArtifact("a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)
 
-        # Break in main() aftre the variables are assigned values.
+        # Break in main() after the variables are assigned values.
         lldbutil.run_break_set_by_file_and_line(
             self, "main.cpp", self.line, num_expected_locations=1, loc_exact=True)
 

Modified: lldb/trunk/packages/Python/lldbsuite/test/functionalities/thread/exit_during_break/main.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/packages/Python/lldbsuite/test/functionalities/thread/exit_during_break/main.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/packages/Python/lldbsuite/test/functionalities/thread/exit_during_break/main.cpp (original)
+++ lldb/trunk/packages/Python/lldbsuite/test/functionalities/thread/exit_during_break/main.cpp Tue May 29 02:10:46 2018
@@ -86,7 +86,7 @@ int main ()
     // last in the internal list maintained by the debugger.
     pseudo_barrier_init(g_barrier1, 5);
 
-    // The second break synchronyizes thread exection with the breakpoint.
+    // The second break synchronizes thread execution with the breakpoint.
     pseudo_barrier_init(g_barrier2, 5);
 
     // The third barrier keeps the waiting threads around until the breakpoint

Modified: lldb/trunk/packages/Python/lldbsuite/test/lang/cpp/unsigned_types/TestUnsignedTypes.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/packages/Python/lldbsuite/test/lang/cpp/unsigned_types/TestUnsignedTypes.py?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/packages/Python/lldbsuite/test/lang/cpp/unsigned_types/TestUnsignedTypes.py (original)
+++ lldb/trunk/packages/Python/lldbsuite/test/lang/cpp/unsigned_types/TestUnsignedTypes.py Tue May 29 02:10:46 2018
@@ -33,7 +33,7 @@ class UnsignedTypesTestCase(TestBase):
         # GCC puts a breakpoint on the last line of a multi-line expression, so
         # if GCC is the target compiler, we cannot rely on an exact line match.
         need_exact = "gcc" not in self.getCompiler()
-        # Break on line 19 in main() aftre the variables are assigned values.
+        # Break on line 19 in main() after the variables are assigned values.
         lldbutil.run_break_set_by_file_and_line(
             self,
             "main.cpp",

Modified: lldb/trunk/packages/Python/lldbsuite/test/lang/objc/bitfield_ivars/TestBitfieldIvars.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/packages/Python/lldbsuite/test/lang/objc/bitfield_ivars/TestBitfieldIvars.py?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/packages/Python/lldbsuite/test/lang/objc/bitfield_ivars/TestBitfieldIvars.py (original)
+++ lldb/trunk/packages/Python/lldbsuite/test/lang/objc/bitfield_ivars/TestBitfieldIvars.py Tue May 29 02:10:46 2018
@@ -5,7 +5,7 @@ lldbinline.MakeInlineTest(
     __file__,
     globals(),
     [
-        # This is a Darwin-only failure related to incorrect expresssion-
+        # This is a Darwin-only failure related to incorrect expression-
         # evaluation for single-bit ObjC bitfields.
         decorators.skipUnlessDarwin,
         decorators.expectedFailureAll(

Modified: lldb/trunk/source/Commands/CommandObjectWatchpointCommand.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Commands/CommandObjectWatchpointCommand.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Commands/CommandObjectWatchpointCommand.cpp (original)
+++ lldb/trunk/source/Commands/CommandObjectWatchpointCommand.cpp Tue May 29 02:10:46 2018
@@ -669,7 +669,7 @@ CommandObjectWatchpointCommand::CommandO
     : CommandObjectMultiword(
           interpreter, "command",
           "Commands for adding, removing and examining LLDB commands "
-          "executed when the watchpoint is hit (watchpoint 'commmands').",
+          "executed when the watchpoint is hit (watchpoint 'commands').",
           "command <sub-command> [<sub-command-options>] <watchpoint-id>") {
   CommandObjectSP add_command_object(
       new CommandObjectWatchpointCommandAdd(interpreter));

Modified: lldb/trunk/source/Core/Communication.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Core/Communication.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Core/Communication.cpp (original)
+++ lldb/trunk/source/Core/Communication.cpp Tue May 29 02:10:46 2018
@@ -105,7 +105,7 @@ ConnectionStatus Communication::Disconne
     //
     // This unique pointer will cleanup after itself when this object goes
     // away, so there is no need to currently have it destroy itself
-    // immediately upon disconnnect.
+    // immediately upon disconnect.
     // connection_sp.reset();
     return status;
   }

Modified: lldb/trunk/source/Core/ValueObjectVariable.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Core/ValueObjectVariable.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Core/ValueObjectVariable.cpp (original)
+++ lldb/trunk/source/Core/ValueObjectVariable.cpp Tue May 29 02:10:46 2018
@@ -201,7 +201,7 @@ bool ValueObjectVariable::UpdateValue()
         // are always load addresses. Host addresses are used to store freeze
         // dried variables. If this type is a struct, the entire struct
         // contents will be copied into the heap of the
-        // LLDB process, but we do not currrently follow any pointers.
+        // LLDB process, but we do not currently follow any pointers.
         if (is_pointer_or_ref)
           SetAddressTypeOfChildren(eAddressTypeLoad);
         else

Modified: lldb/trunk/source/Expression/DWARFExpression.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Expression/DWARFExpression.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Expression/DWARFExpression.cpp (original)
+++ lldb/trunk/source/Expression/DWARFExpression.cpp Tue May 29 02:10:46 2018
@@ -2697,7 +2697,7 @@ bool DWARFExpression::Evaluate(
           if (error_ptr) {
             error_ptr->SetErrorStringWithFormat(
                 "unable to extract DW_OP_bit_piece(bit_size = %" PRIu64
-                ", bit_offset = %" PRIu64 ") from an addresss value.",
+                ", bit_offset = %" PRIu64 ") from an address value.",
                 piece_bit_size, piece_bit_offset);
           }
           return false;

Modified: lldb/trunk/source/Plugins/Architecture/Arm/ArchitectureArm.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/Architecture/Arm/ArchitectureArm.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/Architecture/Arm/ArchitectureArm.cpp (original)
+++ lldb/trunk/source/Plugins/Architecture/Arm/ArchitectureArm.cpp Tue May 29 02:10:46 2018
@@ -94,7 +94,7 @@ void ArchitectureArm::OverrideStopInfo(T
 // such cases, we really don't want to stop at this location.
 // I will check with the lldb-dev list first before I enable this.
 #if 0
-    // ARM mode: check for condition on intsruction
+    // ARM mode: check for condition on instruction
     const addr_t pc = reg_ctx_sp->GetPC();
     Status error;
     // If we fail to read the opcode we will get UINT64_MAX as the result in

Modified: lldb/trunk/source/Plugins/ExpressionParser/Clang/ClangExpressionParser.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/ExpressionParser/Clang/ClangExpressionParser.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/ExpressionParser/Clang/ClangExpressionParser.cpp (original)
+++ lldb/trunk/source/Plugins/ExpressionParser/Clang/ClangExpressionParser.cpp Tue May 29 02:10:46 2018
@@ -803,7 +803,7 @@ lldb_private::Status ClangExpressionPars
   {
     auto lang = m_expr.Language();
     if (log)
-      log->Printf("%s - Currrent expression language is %s\n", __FUNCTION__,
+      log->Printf("%s - Current expression language is %s\n", __FUNCTION__,
                   Language::GetNameForLanguageType(lang));
     lldb::ProcessSP process_sp = exe_ctx.GetProcessSP();
     if (process_sp && lang != lldb::eLanguageTypeUnknown) {

Modified: lldb/trunk/source/Plugins/LanguageRuntime/RenderScript/RenderScriptRuntime/RenderScriptRuntime.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/LanguageRuntime/RenderScript/RenderScriptRuntime/RenderScriptRuntime.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/LanguageRuntime/RenderScript/RenderScriptRuntime/RenderScriptRuntime.cpp (original)
+++ lldb/trunk/source/Plugins/LanguageRuntime/RenderScript/RenderScriptRuntime/RenderScriptRuntime.cpp Tue May 29 02:10:46 2018
@@ -593,7 +593,7 @@ struct RenderScriptRuntime::Element {
   empirical_type<uint32_t> datum_size;  // Size of a single Element with padding
   empirical_type<uint32_t> padding;     // Number of padding bytes
   empirical_type<uint32_t>
-      array_size;        // Number of items in array, only needed for strucrs
+      array_size;        // Number of items in array, only needed for structs
   ConstString type_name; // Name of type, only needed for structs
 
   static const ConstString &
@@ -3392,7 +3392,7 @@ bool RenderScriptRuntime::DumpAllocation
           DumpValueObjectOptions expr_options;
           expr_options.SetHideName(true);
 
-          // Setup expression as derefrencing a pointer cast to element
+          // Setup expression as dereferencing a pointer cast to element
           // address.
           char expr_char_buffer[jit_max_expr_size];
           int written =

Modified: lldb/trunk/source/Plugins/LanguageRuntime/RenderScript/RenderScriptRuntime/RenderScriptx86ABIFixups.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/LanguageRuntime/RenderScript/RenderScriptRuntime/RenderScriptx86ABIFixups.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/LanguageRuntime/RenderScript/RenderScriptRuntime/RenderScriptx86ABIFixups.cpp (original)
+++ lldb/trunk/source/Plugins/LanguageRuntime/RenderScript/RenderScriptRuntime/RenderScriptx86ABIFixups.cpp Tue May 29 02:10:46 2018
@@ -121,7 +121,7 @@ llvm::FunctionType *cloneToStructRetFnTy
   if (log)
     log->Printf("%s - return type pointer type for StructRet clone @ '0x%p':\n",
                 __FUNCTION__, (void *)return_type_ptr_type);
-  // put the the sret pointer argument in place at the beginning of the
+  // put the sret pointer argument in place at the beginning of the
   // argument list.
   params.emplace(params.begin(), return_type_ptr_type);
   assert(params.size() == num_params + 1);

Modified: lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm.h?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm.h (original)
+++ lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm.h Tue May 29 02:10:46 2018
@@ -42,7 +42,7 @@ public:
   Status WriteAllRegisterValues(const lldb::DataBufferSP &data_sp) override;
 
   //------------------------------------------------------------------
-  // Hardware breakpoints/watchpoint mangement functions
+  // Hardware breakpoints/watchpoint management functions
   //------------------------------------------------------------------
 
   uint32_t NumSupportedHardwareBreakpoints() override;
@@ -140,7 +140,7 @@ private:
                            // occurred.
     lldb::addr_t real_addr; // Address value that should cause target to stop.
     uint32_t control;       // Breakpoint/watchpoint control value.
-    uint32_t refcount;      // Serves as enable/disable and refernce counter.
+    uint32_t refcount;      // Serves as enable/disable and reference counter.
   };
 
   struct DREG m_hbr_regs[16]; // Arm native linux hardware breakpoints

Modified: lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.h?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.h (original)
+++ lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.h Tue May 29 02:10:46 2018
@@ -42,7 +42,7 @@ public:
   Status WriteAllRegisterValues(const lldb::DataBufferSP &data_sp) override;
 
   //------------------------------------------------------------------
-  // Hardware breakpoints/watchpoint mangement functions
+  // Hardware breakpoints/watchpoint management functions
   //------------------------------------------------------------------
 
   uint32_t NumSupportedHardwareBreakpoints() override;
@@ -140,7 +140,7 @@ private:
                            // occurred.
     lldb::addr_t real_addr; // Address value that should cause target to stop.
     uint32_t control;       // Breakpoint/watchpoint control value.
-    uint32_t refcount;      // Serves as enable/disable and refernce counter.
+    uint32_t refcount;      // Serves as enable/disable and reference counter.
   };
 
   struct DREG m_hbr_regs[16]; // Arm native linux hardware breakpoints

Modified: lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_ppc64le.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_ppc64le.h?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_ppc64le.h (original)
+++ lldb/trunk/source/Plugins/Process/Linux/NativeRegisterContextLinux_ppc64le.h Tue May 29 02:10:46 2018
@@ -49,7 +49,7 @@ public:
   Status WriteAllRegisterValues(const lldb::DataBufferSP &data_sp) override;
 
   //------------------------------------------------------------------
-  // Hardware watchpoint mangement functions
+  // Hardware watchpoint management functions
   //------------------------------------------------------------------
 
   uint32_t NumSupportedHardwareWatchpoints() override;

Modified: lldb/trunk/source/Plugins/Process/Linux/ProcessorTrace.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/Process/Linux/ProcessorTrace.h?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/Process/Linux/ProcessorTrace.h (original)
+++ lldb/trunk/source/Plugins/Process/Linux/ProcessorTrace.h Tue May 29 02:10:46 2018
@@ -34,7 +34,7 @@ namespace process_linux {
 // a key to the tracing instance and trace manipulations could be
 // performed using the trace id.
 //
-// The traace id could map to trace instances for a group of threads
+// The trace id could map to trace instances for a group of threads
 // (spanning to all the threads in the process) or a single thread.
 // The kernel interface for us is the perf_event_open.
 // ---------------------------------------------------------------------

Modified: lldb/trunk/source/Plugins/Process/MacOSX-Kernel/ProcessKDP.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/Process/MacOSX-Kernel/ProcessKDP.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/Process/MacOSX-Kernel/ProcessKDP.cpp (original)
+++ lldb/trunk/source/Plugins/Process/MacOSX-Kernel/ProcessKDP.cpp Tue May 29 02:10:46 2018
@@ -385,7 +385,7 @@ ProcessKDP::DoAttachToProcessWithID(lldb
                                     const ProcessAttachInfo &attach_info) {
   Status error;
   error.SetErrorString(
-      "attach to process by ID is not suppported in kdp remote debugging");
+      "attach to process by ID is not supported in kdp remote debugging");
   return error;
 }
 
@@ -394,7 +394,7 @@ ProcessKDP::DoAttachToProcessWithName(co
                                       const ProcessAttachInfo &attach_info) {
   Status error;
   error.SetErrorString(
-      "attach to process by name is not suppported in kdp remote debugging");
+      "attach to process by name is not supported in kdp remote debugging");
   return error;
 }
 
@@ -544,7 +544,7 @@ Status ProcessKDP::DoHalt(bool &caused_s
 
   if (m_comm.IsRunning()) {
     if (m_destroy_in_process) {
-      // If we are attemping to destroy, we need to not return an error to Halt
+      // If we are attempting to destroy, we need to not return an error to Halt
       // or DoDestroy won't get called. We are also currently running, so send
       // a process stopped event
       SetPrivateState(eStateStopped);
@@ -646,14 +646,14 @@ size_t ProcessKDP::DoWriteMemory(addr_t
 lldb::addr_t ProcessKDP::DoAllocateMemory(size_t size, uint32_t permissions,
                                           Status &error) {
   error.SetErrorString(
-      "memory allocation not suppported in kdp remote debugging");
+      "memory allocation not supported in kdp remote debugging");
   return LLDB_INVALID_ADDRESS;
 }
 
 Status ProcessKDP::DoDeallocateMemory(lldb::addr_t addr) {
   Status error;
   error.SetErrorString(
-      "memory deallocation not suppported in kdp remote debugging");
+      "memory deallocation not supported in kdp remote debugging");
   return error;
 }
 
@@ -700,14 +700,14 @@ Status ProcessKDP::DisableBreakpointSite
 Status ProcessKDP::EnableWatchpoint(Watchpoint *wp, bool notify) {
   Status error;
   error.SetErrorString(
-      "watchpoints are not suppported in kdp remote debugging");
+      "watchpoints are not supported in kdp remote debugging");
   return error;
 }
 
 Status ProcessKDP::DisableWatchpoint(Watchpoint *wp, bool notify) {
   Status error;
   error.SetErrorString(
-      "watchpoints are not suppported in kdp remote debugging");
+      "watchpoints are not supported in kdp remote debugging");
   return error;
 }
 
@@ -716,7 +716,7 @@ void ProcessKDP::Clear() { m_thread_list
 Status ProcessKDP::DoSignal(int signo) {
   Status error;
   error.SetErrorString(
-      "sending signals is not suppported in kdp remote debugging");
+      "sending signals is not supported in kdp remote debugging");
   return error;
 }
 

Modified: lldb/trunk/source/Plugins/Process/gdb-remote/ProcessGDBRemote.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/Process/gdb-remote/ProcessGDBRemote.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/Process/gdb-remote/ProcessGDBRemote.cpp (original)
+++ lldb/trunk/source/Plugins/Process/gdb-remote/ProcessGDBRemote.cpp Tue May 29 02:10:46 2018
@@ -5002,7 +5002,7 @@ ParseStructuredDataPacket(llvm::StringRe
   if (!packet.consume_front(s_async_json_packet_prefix)) {
     if (log) {
       log->Printf(
-          "GDBRemoteCommmunicationClientBase::%s() received $J packet "
+          "GDBRemoteCommunicationClientBase::%s() received $J packet "
           "but was not a StructuredData packet: packet starts with "
           "%s",
           __FUNCTION__,

Modified: lldb/trunk/source/Plugins/StructuredData/DarwinLog/StructuredDataDarwinLog.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/StructuredData/DarwinLog/StructuredDataDarwinLog.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/StructuredData/DarwinLog/StructuredDataDarwinLog.cpp (original)
+++ lldb/trunk/source/Plugins/StructuredData/DarwinLog/StructuredDataDarwinLog.cpp Tue May 29 02:10:46 2018
@@ -185,7 +185,7 @@ const char *const s_filter_attributes[]
     "message",        // message contents, fully expanded
     "subsystem"       // subsystem of the log message
 
-    // Consider impelmenting this action as it would be cheaper to filter.
+    // Consider implementing this action as it would be cheaper to filter.
     // "message" requires always formatting the message, which is a waste of
     // cycles if it ends up being rejected. "format",      // format string
     // used to format message text
@@ -488,11 +488,11 @@ static OptionDefinition g_enable_option_
      "a log message."},
     {LLDB_OPT_SET_ALL, false, "category", 'c', OptionParser::eNoArgument,
      nullptr, nullptr, 0, eArgTypeNone,
-     "Include the category in the the message header when displaying "
+     "Include the category in the message header when displaying "
      "a log message."},
     {LLDB_OPT_SET_ALL, false, "activity-chain", 'C', OptionParser::eNoArgument,
      nullptr, nullptr, 0, eArgTypeNone,
-     "Include the activity parent-child chain in the the message header "
+     "Include the activity parent-child chain in the message header "
      "when displaying a log message.  The activity hierarchy is "
      "displayed as {grandparent-activity}:"
      "{parent-activity}:{activity}[:...]."},
@@ -615,7 +615,7 @@ public:
 
     source_flags_sp->AddBooleanItem("any-process", m_include_any_process);
     source_flags_sp->AddBooleanItem("debug-level", m_include_debug_level);
-    // The debug-level flag, if set, implies info-level.
+    // The debug-level flag, if set, implies info-level.
     source_flags_sp->AddBooleanItem("info-level", m_include_info_level ||
                                                       m_include_debug_level);
     source_flags_sp->AddBooleanItem("live-stream", m_live_stream);
@@ -877,7 +877,7 @@ protected:
       plugin.SetEnabled(false);
     } else {
       result.SetStatus(eReturnStatusSuccessFinishNoResult);
-      // Our configuration succeeeded, so we're enabled/disabled per whichever
+      // Our configuration succeeded, so we're enabled/disabled per whichever
       // one this command is setup to do.
       plugin.SetEnabled(m_enable);
     }
@@ -1461,7 +1461,7 @@ Status StructuredDataDarwinLog::FilterLa
 
   // Darwin os_log() support automatically adds debug-level and info-level
   // messages when a debugger is attached to a process.  However, with
-  // integrated suppport for debugging built into the command-line LLDB, the
+  // integrated support for debugging built into the command-line LLDB, the
   // user may specifically set to *not* include debug-level and info-level
   // content.  When the user is using the integrated log support, we want to
   // put the kabosh on that automatic adding of info and debug level. This is

Modified: lldb/trunk/source/Plugins/UnwindAssembly/InstEmulation/UnwindAssemblyInstEmulation.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/UnwindAssembly/InstEmulation/UnwindAssemblyInstEmulation.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/UnwindAssembly/InstEmulation/UnwindAssemblyInstEmulation.cpp (original)
+++ lldb/trunk/source/Plugins/UnwindAssembly/InstEmulation/UnwindAssemblyInstEmulation.cpp Tue May 29 02:10:46 2018
@@ -159,7 +159,7 @@ bool UnwindAssemblyInstEmulation::GetNon
 
             // If the offset of m_curr_row don't match with the offset we see
             // in saved_unwind_states then we have to update m_curr_row and
-            // m_register_values based on the saved values. It is happenning
+            // m_register_values based on the saved values. It is happening
             // after we processed an epilogue and a return to caller
             // instruction.
             if (it->second.first->GetOffset() != m_curr_row->GetOffset()) {
@@ -206,7 +206,7 @@ bool UnwindAssemblyInstEmulation::GetNon
                     replace_existing);
               }
 
-              // We are starting a new conditional block at the catual offset
+              // We are starting a new conditional block at the actual offset
               condition_block_start_offset = current_offset;
             }
 
@@ -242,7 +242,7 @@ bool UnwindAssemblyInstEmulation::GetNon
             // instruction?
             if (m_curr_row_modified) {
               // Save the modified row if we don't already have a CFI row in
-              // the currennt address
+              // the current address
               if (saved_unwind_states.count(
                       current_offset + inst->GetOpcode().GetByteSize()) == 0) {
                 m_curr_row->SetOffset(current_offset +

Modified: lldb/trunk/source/Target/TargetList.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Target/TargetList.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Target/TargetList.cpp (original)
+++ lldb/trunk/source/Target/TargetList.cpp Tue May 29 02:10:46 2018
@@ -102,7 +102,7 @@ Status TargetList::CreateTargetInternal(
 
   CommandInterpreter &interpreter = debugger.GetCommandInterpreter();
 
-  // let's see if there is already an existing plaform before we go creating
+  // let's see if there is already an existing platform before we go creating
   // another...
   platform_sp = debugger.GetPlatformList().GetSelectedPlatform();
 
@@ -232,7 +232,7 @@ Status TargetList::CreateTargetInternal(
           }
 
           if (platform_ptr) {
-            // All platforms for all modules in the exectuable match, so we can
+            // All platforms for all modules in the executable match, so we can
             // select this platform
             platform_sp = platforms.front();
           } else if (more_than_one_platforms == false) {

Modified: lldb/trunk/source/Utility/Status.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Utility/Status.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/source/Utility/Status.cpp (original)
+++ lldb/trunk/source/Utility/Status.cpp Tue May 29 02:10:46 2018
@@ -167,7 +167,7 @@ ErrorType Status::GetType() const { retu
 bool Status::Fail() const { return m_code != 0; }
 
 //----------------------------------------------------------------------
-// Set accesssor for the error value to "err" and the type to
+// Set accessor for the error value to "err" and the type to
 // "eErrorTypeMachKernel"
 //----------------------------------------------------------------------
 void Status::SetMachError(uint32_t err) {
@@ -201,7 +201,7 @@ int Status::SetExpressionErrorWithFormat
 }
 
 //----------------------------------------------------------------------
-// Set accesssor for the error value and type.
+// Set accessor for the error value and type.
 //----------------------------------------------------------------------
 void Status::SetError(ValueType err, ErrorType type) {
   m_code = err;

Modified: lldb/trunk/tools/debugserver/source/MacOSX/MachProcess.mm
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/debugserver/source/MacOSX/MachProcess.mm?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/tools/debugserver/source/MacOSX/MachProcess.mm (original)
+++ lldb/trunk/tools/debugserver/source/MacOSX/MachProcess.mm Tue May 29 02:10:46 2018
@@ -1486,7 +1486,7 @@ bool MachProcess::Detach() {
   // Resume our task
   m_task.Resume();
 
-  // NULL our task out as we have already retored all exception ports
+  // NULL our task out as we have already restored all exception ports
   m_task.Clear();
 
   // Clear out any notion of the process we once were
@@ -1797,7 +1797,7 @@ bool MachProcess::DisableBreakpoint(nub_
           break_op_size) {
         bool verify = false;
         if (bp->IsEnabled()) {
-          // Make sure we have the a breakpoint opcode exists at this address
+          // Make sure a breakpoint opcode exists at this address
           if (memcmp(curr_break_op, break_op, break_op_size) == 0) {
             break_op_found = true;
             // We found a valid breakpoint opcode at this address, now restore

Modified: lldb/trunk/tools/debugserver/source/RNBServices.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/debugserver/source/RNBServices.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/tools/debugserver/source/RNBServices.cpp (original)
+++ lldb/trunk/tools/debugserver/source/RNBServices.cpp Tue May 29 02:10:46 2018
@@ -80,7 +80,7 @@ int GetProcesses(CFMutableArrayRef plist
       ::CFDictionarySetValue(appInfoDict.get(), DTSERVICES_APP_PID_KEY,
                              pidCFNumber.get());
 
-      // Set the a boolean to indicate if this is the front most
+      // Set a boolean to indicate if this is the front most
       ::CFDictionarySetValue(appInfoDict.get(), DTSERVICES_APP_FRONTMOST_KEY,
                              kCFBooleanFalse);
 
@@ -169,7 +169,7 @@ int ListApplications(std::string &plist,
                                pidCFNumber.get());
       }
 
-      // Set the a boolean to indicate if this is the front most
+      // Set a boolean to indicate if this is the front most
       if (sbsFrontAppID.get() && displayIdentifier &&
           (::CFStringCompare(sbsFrontAppID.get(), displayIdentifier, 0) ==
            kCFCompareEqualTo))

Modified: lldb/trunk/tools/lldb-mi/MICmnResources.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnResources.cpp?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnResources.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnResources.cpp Tue May 29 02:10:46 2018
@@ -451,7 +451,7 @@ const CMICmnResources::SRsrcTextData
          "'print' error. The option '%s' not found"},
         {IDS_CMD_ERR_EXPR_INVALID, "Failed to evaluate expression: %s"},
         {IDS_CMD_ERR_ATTACH_FAILED,
-         "Command '%s'. Attach to processs failed: %s"},
+         "Command '%s'. Attach to process failed: %s"},
         {IDS_CMD_ERR_ATTACH_BAD_ARGS,
          "Command '%s'. Must specify either a PID or a Name"}};
 

Modified: lldb/trunk/tools/lldb-mi/MIReadMe.txt
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MIReadMe.txt?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MIReadMe.txt (original)
+++ lldb/trunk/tools/lldb-mi/MIReadMe.txt Tue May 29 02:10:46 2018
@@ -9,7 +9,7 @@ For help information on using the MI dri
 
 	lldb-mi --interpreter --help
 
-A blog about the MI Driver is available on CodePlay's website. ALthough it may not be
+A blog about the MI Driver is available on CodePlay's website. Although it may not be
 completely accurate after the recent changes in lldb-mi.
 http://www.codeplay.com/portal/lldb-mi-driver---part-1-introduction
 
@@ -19,7 +19,7 @@ used to aid the debugging of the MI Driv
 command's which do not support certain argument or options.  
 
 Note any command or text sent to the MI Driver in MI mode that is not a command 
-registered in the MI Driver's Command Factory will be rejected and an error messsage
+registered in the MI Driver's Command Factory will be rejected and an error message
 will be generated.
 
 All the files prefix with MI are specifically for the MI driver code only.
@@ -29,8 +29,8 @@ File MIDriverMain.cpp contains the execu
 Current limitations:
 1. Not all commands and their options have been implemented. Please see
 the source code for details.
-2. LLDB-MI may have additinal arguments not used in GDB MI. Please see
-MIExtesnsions.txt
+2. LLDB-MI may have additional arguments not used in GDB MI. Please see
+MIExtensions.txt
 
 =========================================================================
 The MI Driver build configuration:

Modified: lldb/trunk/www/remote.html
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/www/remote.html?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/www/remote.html (original)
+++ lldb/trunk/www/remote.html Tue May 29 02:10:46 2018
@@ -133,7 +133,7 @@
               "<code>remote-</code>". For example, to debug a remote Linux application:
             <br>
             <code>
-              <br>(lldb) <b>patform select remote-linux</b>
+              <br>(lldb) <b>platform select remote-linux</b>
             </code>
 
             <p>
@@ -215,7 +215,7 @@
             <h4>Install and run by specifying a remote install path</h4>
             <p>
               If you want the "a.out" executable to be installed into
-              "/bin/a.out" instead of the platorm's current working directory,
+              "/bin/a.out" instead of the platform's current working directory,
               we can set the platform file specification using python:
             <br>
             <code>
@@ -225,7 +225,7 @@
             </code>
             <p>
               Now when you run your program, the program will be uploaded to
-              "/bin/a.out" instead of the the platform current working directory.
+              "/bin/a.out" instead of the platform current working directory.
               Only the main executable is uploaded to the remote system by
               default when launching the application. If you have shared
               libraries that should also be uploaded, then you can add the

Modified: lldb/trunk/www/tutorial.html
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/www/tutorial.html?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================
--- lldb/trunk/www/tutorial.html (original)
+++ lldb/trunk/www/tutorial.html Tue May 29 02:10:46 2018
@@ -94,7 +94,7 @@
                     </code>
 
                    <p>You can use the --name option multiple times to make a breakpoint on a set of functions as well.  This is convenient
-                      since it allows you to set commmon conditions or commands without having to specify them multiple times:</p>
+                      since it allows you to set common conditions or commands without having to specify them multiple times:</p>
 
                     <code>
                         (lldb) breakpoint set --name foo --name bar




More information about the lldb-commits mailing list
--- lldb/trunk/packages/Python/lldbsuite/test/functionalities/apropos_with_process/TestAproposWithProcess.py (original)
+++ lldb/trunk/packages/Python/lldbsuite/test/functionalities/apropos_with_process/TestAproposWithProcess.py Tue May 29 02:10:46 2018
@@ -1,5 +1,5 @@
 """
-Test that apropos env doesn't crash trying to touch the process plugin commmand
+Test that apropos env doesn't crash trying to touch the process plugin command
 """
 
 from __future__ import print_function
@@ -24,12 +24,12 @@ class AproposWithProcessTestCase(TestBas
         self.line = line_number('main.cpp', '// break here')
 
     def test_apropos_with_process(self):
         """Test that apropos env doesn't crash trying to touch the process plugin commmand."""
         self.build()
         exe = self.getBuildArtifact("a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)
 
-        # Break in main() aftre the variables are assigned values.
+        # Break in main() after the variables are assigned values.
         lldbutil.run_break_set_by_file_and_line(
             self, "main.cpp", self.line, num_expected_locations=1, loc_exact=True)
 
@@ -24,12 +24,12 @@ class AproposWithProcessTestCase(TestBas
 
     def test_apropos_with_process(self):
-        """Test that apropos env doesn't crash trying to touch the process plugin commmand."""
+        """Test that apropos env doesn't crash trying to touch the process plugin command."""
         self.build()
         exe = self.getBuildArtifact("a.out")

Modified: lldb/trunk/packages/Python/lldbsuite/test/functionalities/memory/find/TestMemoryFind.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/packages/Python/lldbsuite/test/functionalities/memory/find/TestMemoryFind.py?rev=333399&r1=333398&r2=333399&view=diff
==============================================================================